@@ -4,6 +4,7 @@ import urlparse
 import os
 
 from rospkg.os_detect import OS_UBUNTU
+from rospkg.os_detect import OS_DEBIAN
 from rospkg.os_detect import OS_OSX
 
 from .core import InvalidData, DownloadFailure
@@ -157,6 +158,11 @@ def get_gbprepo_as_rosdep_data(gbpdistro):
             deb_package_name = 'ros-%s-%s' % (release_name, pkg)
             deb_package_name = deb_package_name.replace('_', '-')
 
+            # Generate debian entries
+            rosdep_data[pkg][OS_DEBIAN] = {
+                APT_INSTALLER: {'packages': [deb_package_name]}
+            }
+
             for os_name in distro_file.platforms:
                 for os_code_name in distro_file.platforms[os_name]:
                     rosdep_data[pkg][os_name][os_code_name] = {
